/* 
 * tclVmsSock.c --
 *
 *	This file contains VMS-specific socket related code.
 *
 */

#include "tcl.h"
#include "tclPort.h"

/*
 * The following variable holds the network name of this host.
 */

#ifndef SYS_NMLN
#   define SYS_NMLN 100
#endif

static char hostname[SYS_NMLN + 1];
static int  hostnameInited = 0;

/*
 *----------------------------------------------------------------------
 *
 * Tcl_GetHostName --
 *
 *	Get the network name for this machine, in a system dependent way.
 *
 * Results:
 *	A string containing the network name for this machine, or
 *	an empty string if we can't figure out the name.
 *
 * Side effects:
 *	None.
 *
 *----------------------------------------------------------------------
 */

char *
Tcl_GetHostName()
{
#ifndef __VMS
#ifndef NO_UNAME
    struct utsname u;
    struct hostent *hp;
#endif
#endif	/* !__VMS */

    if (hostnameInited) {
        return hostname;
    }

#ifndef __VMS
#ifndef NO_UNAME
    if (uname(&u) > -1) {
        hp = gethostbyname(u.nodename);
        if (hp != NULL) {
            strcpy(hostname, hp->h_name);
        } else {
            strcpy(hostname, u.nodename);
        }
        hostnameInited = 1;
        return hostname;
    }
#else
#endif	/* !__VMS */
    /*
     * Uname doesn't exist; try gethostname instead.
     */

    if (multinet_gethostname(hostname, sizeof(hostname)) > -1) {
	hostnameInited = 1;
        return hostname;
    }
#ifndef __VMS
#endif
#endif	/* !__VMS */

    hostname[0] = 0;
    return hostname;
}
